//
//  IKAction.h
//  YoupiKey
//
//  Created by phupe on Sat Jan 20 2001.
//  Copyright (c) 2001 Philippe HUP. All rights reserved.
//


#import <Cocoa/Cocoa.h>
#import <Carbon/Carbon.h>
#import "IKConstant.h"

@protocol IKActionController

- (BOOL)canGoRunning;
- (BOOL)canGoRunningAfterError:(NSString *)errorString;
- (void)stopRunning;
- (void)setErrorWhenRunning:(NSString *)errorString action:(id)ranAction;
- (void)setActionTerminatesWithoutError:(id)ranAction;

@end

@interface IKAction : NSObject <IKActionController>

{
@private
NSString *IKAName;				//shortcut name
unsigned int IKAID;
NSImage *IKAImage;				//shortcut icon

}

//Utilitaires
+ (NSOpenPanel *)openDocumentPanel;
+ (NSString *)resolveAliasPath:(NSString*)path;
+ (int)typeForPath:(NSString *)path;
+ (int)typeForTargetPath:(NSString *)path;
+ (NSString *)targetPath:(NSString *)path;
+ (NSData *)FSRefForPath:(NSString *)path;
+ (NSString *)pathForFSRef:(NSData *)FSRefData;
+ (NSData *)iconDataForPath:(NSString *)path withSize:(int)size;
+ (NSImage *)iconImageForPath:(NSString *)path withSize:(int)size;
+ (NSImage *)unknownIconWithSize:(int)size;
+ (int)runScript:(NSString *)scriptString;
+ (UInt8)asciiForKeycode:(UInt32)keycode; //renvoi le code ascii  partir d'un keycode
+ (NSString *)modifierStringWithKeycode:(UInt32)keycode;
+ (NSImage *)imageInBundle:(NSBundle *)bundle named:(NSString *)imageName;
+ (NSString *)getApplicationFromPath:(NSString *)path;
+ (NSString *)getFolderFromPath:(NSString *)path;
+ (NSString *)getDocumentOfTypes:(NSArray *)docTypes fromPath:(NSString *)path;
+ (BOOL)isTextFileAtPath:(NSString *)path;
+ (NSString *)stringWithPath:(NSString *)path;
+ (void)openPreferencePanel:(NSString *)panelName;
+ (int)runAlertPanelWithTitle:(NSString *)title message:(NSString *)msg button1:(NSString *)defaultButton button2:(NSString *)alternateButton button3:(NSString *)otherButton;
+ (void)displayFloatingMenu:(NSMenu *)menu;
+ (void)typeAsciiChar:(UInt8)asciiChar;
+ (UInt32)asciiKeycodesForAsciiChar:(UInt8)asciiChar;
+ (void)saveModifierState:(UInt32)modifierState onlyModifiers:(BOOL)onlyModifiers;
+ (void)restoreModifierState;
+ (void)resetModifierState;
+ (SInt32)systemVersion;
+ (BOOL)canRunAsAdmin;
+ (void)startRunAsAdmin;
+ (void)stopRunAsAdmin;

//Par dfaut d'une classe de plugin
+ (void)setRegistered:(BOOL)registered;
+ (BOOL)registered;
+ (void)setRegisterStartDate:(NSCalendarDate *)startDate;
+ (void)controlRunAction:(IKAction *)runAction;
+ (NSImage *)defaultIcon;

//protocole IKActionController
+ (BOOL)canGoRunning;
+ (BOOL)canGoRunningAfterError:(NSString *)errorString;
+ (void)stopRunning;
+ (void)setErrorWhenRunning:(NSString *)errorString action:(id)ranAction;
+ (void)setActionTerminatesWithoutError:(id)ranAction;

//initialisation
- (id)initWithDictionaryInLauncher:(NSDictionary *)actionDict;
- (void)dealloc;

//obtenir des paramtres
- (NSImage *)imageValue;
- (NSImage *)imageValueWithSize:(int)size;
- (NSString *)nameValue;
- (BOOL)nameIsEqual:(NSString *)theName;
- (unsigned int)IDValue;
- (BOOL)IDIsEqual:(unsigned int)anID;
- (float)runDelay;

- (void)runObject;
- (void)runActionFromObjectInThread:(id<IKActionController>)object;
- (NSString *)runActionFromObject:(id<IKActionController>)object;
- (BOOL)addToRecent;

//pour Applescript
- (NSString *)name;
- (id)runCommand:(NSScriptCommand *)command;


@end
