//
//  IKAction.h
//  YoupiKey
//
//  Created by phupe on Sat Jan 20 2001.
//  Copyright (c) 2001 Philippe HUP. All rights reserved.
//


#import <Cocoa/Cocoa.h>
#import <Carbon/Carbon.h>
#import "IKConstant.h"

@interface IKAction : NSObject <IKEAuxObject>

{
@private
NSMutableDictionary *IKADict;		//shortcut dictionary (data)
NSString *IKAName;				//shortcut name
unsigned int IKAID;
NSImage *IKAImage;				//shortcut icon
id IKAEditor;
NSUndoManager *IKAUndoManager;
NSDictionary *IKAPrivateDict;			//utilis uniquement si le plugin n'est pas prsent
BOOL IKAIsNew;
NSMutableArray *IKALinkedObjects;

NSImage *IKAFamilyImage;
NSImage *IKATypeImage;

NSRect IKAEditorRect;

}


//Utilitaires
+ (NSOpenPanel *)openDocumentPanel;
+ (NSString *)resolveAliasPath:(NSString*)path;
+ (int)typeForPath:(NSString *)path;
+ (int)typeForTargetPath:(NSString *)path;
+ (NSString *)targetPath:(NSString *)path;
+ (NSData *)FSRefForPath:(NSString *)path;
+ (NSString *)pathForFSRef:(NSData *)FSRefData;
+ (NSData *)iconDataForPath:(NSString *)path withSize:(int)size;
+ (NSImage *)iconImageForPath:(NSString *)path withSize:(int)size;
+ (NSImage *)unknownIconWithSize:(int)size;
+ (int)runScript:(NSString *)scriptString;
+ (UInt8)asciiForKeycode:(UInt32)keycode; //renvoi le code ascii  partir d'un keycode
+ (NSString *)modifierStringWithKeycode:(UInt32)keycode;
+ (NSImage *)imageInBundle:(NSBundle *)bundle named:(NSString *)imageName;
+ (NSString *)getApplicationFromPath:(NSString *)path;
+ (NSString *)getFolderFromPath:(NSString *)path;
+ (NSString *)getDocumentOfTypes:(NSArray *)docTypes fromPath:(NSString *)path;
+ (BOOL)isTextFileAtPath:(NSString *)path;
+ (NSString *)stringWithPath:(NSString *)path;
+ (void)openPreferencePanel:(NSString *)panelName;
+ (NSArray *)launchedAppPathArray;
+ (NSArray *)recentAppPathArray;
+ (void)playClicSound;

//Par dfaut d'une classe de plugin
+ (NSNumber *)objectIndex;
+ (int)categoryOfAction:(int)action;
+ (int)familyID;
+ (NSArray *)modelsID;
+ (NSImage *)imageForFamilyID:(int)familyID withSize:(int)imageSize;
+ (NSString *)nameOfImageForModelID:(int)modelID;
+ (NSImage *)imageForModelID:(int)modelID withSize:(int)imageSize;
+ (NSString *)titleOfModelID:(int)modelID;
+ (NSString *)descriptionOfModelID:(int)modelID;
//+ (void)showHelpForModelID:(int)modelID;
+ (NSString *)newNameValue;
+ (NSDictionary *)newDataForClass:(Class)cutClass;
+ (unsigned int)nextActionID;
+ (unsigned int)currentActionID;
+ (void)setNextActionID:(unsigned int)nextID;
+ (NSDictionary *)newDataForAction:(int)action;
//+ (void)setMessageNonValid:(BOOL)message;
//+ (BOOL)messageNonValid;
+ (NSArray *)pasteboardTypes;
+ (NSArray *)modelsIDForPasteboard:(NSPasteboard *)pboard;
+ (NSArray *)newDatasWithPasteboard:(NSPasteboard *)pboard forAction:(int)action;

//Pour l'diteur
+ (void)setSuggestNameNew:(BOOL)suggest;
+ (BOOL)suggestNameNew;
+ (void)setSuggestNameModified:(BOOL)suggest;
+ (BOOL)suggestNameModified;
+ (NSImage *)defaultIcon;
+ (NSString *)typeName;

//initialisation
- (id)initWithDictionaryInEditor:(NSDictionary *)actionDict;
- (void)dealloc;

//obtenir des paramtres
- (int)modelID;
- (NSDictionary *)dictValue;
- (NSDictionary *)dataValue;
- (BOOL)canDeleteWithMessage:(BOOL)withMessage;
- (BOOL)isValid;
- (NSString *)notValidString;
- (BOOL)isNew;
- (NSImage *)imageValue;
- (NSImage *)imageValueWithSize:(int)size;
- (NSString *)possibleNameValue;
- (NSString *)nameValue;
- (NSString *)typeNameValue;
- (NSString *)linkNameValue;
- (NSString *)descriptionValue;
- (unsigned int)IDValue;
- (BOOL)IDIsEqual:(unsigned int)anID;
- (NSArray *)linkedObjects;
//- (NSNumber *)usedValue;
//- (NSString *)linksValue;
//- (NSImage *)linksImageValue;
- (NSImage *)familyImageValue;
- (NSImage *)typeImageValue;
- (NSNumber *)familyValue;
- (NSNumber *)typeValue;
- (NSRect)editorRect;
- (BOOL)isUsed;
- (BOOL)isEqualActionOfClass:(NSString *)className withParams:(NSDictionary *)paramsDict;
- (BOOL)canTest;

//dfinir des paramtres
- (void)setIsNew:(BOOL)isNew;
- (void)setPossibleImageValue:(NSImage *)possibleImage;
- (void)setNameValue:(NSString *)actionName;
- (void)setPossibleNameValue:(NSString *)actionName;
- (void)setPossibleDescriptionValue:(NSString *)description;
- (void)setEditorRect:(NSRect)aRect;

//excuter une action
- (BOOL)edit;
- (void)editInEditor:(id)editor;
- (void)closeEditor;
- (BOOL)editorWantKeyEvent;
- (void)editorKeyEvent:(NSEvent *)anEvent;
- (void)windowDidBecomeKey:(NSNotification *)aNotification;
- (void)windowDidResignKey:(NSNotification *)aNotification;
- (void)displayNotValid;
- (void)willEditInEditor:(id)editor withAccessoryView:(NSView *)accessoryView;
- (BOOL)wantKeyEvent;
- (void)keyEvent:(NSEvent *)anEvent;
- (BOOL)willValidateEditing;
- (void)abortEditing;
- (NSDictionary *)editedDictValue;
- (NSDictionary *)editedDataValue;
- (void)releaseEditor;
- (void)showHelp;
- (void)willDelete;
- (void)addLinkedObject:(id)anObject;
- (void)removeLinkedObject:(id)anObject;
- (BOOL)isLinkedToObject:(id)object;
- (void)removeAllLinkedObject;
- (void)test;
- (void)testEditedObject;

//pour la gestion des annulations
- (NSUndoManager *)undoManager;
- (NSUndoManager *)windowWillReturnUndoManager:(NSWindow *)sender;

@end
